//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCMESSAGEDIALOG_H
#define WSCMESSAGEDIALOG_H

#include <WScom.h>
#include <WSCbaseDialog.h>

#define WSCmessageDialog_VER 1000

class WSCmessageDialog :public WSCbaseDialog{

  protected:
    char* _label_string;
    WSCform*   _area1;
    WSCvlabel*  _label;
    short     _wbg_no;

    WSMFpropertyDef( WSNlabelString,   char*,   _label_string ); 
    WSMFpropertyDef( WSNworkBackColor,  short,      _wbg_no );
      

  public:
    WSDLEX32 WSCmessageDialog(WSCbase*,char*);
    WSDLEX32 virtual ~WSCmessageDialog();
    WSDLEX32 virtual  long initialize();

//    virtual void onResize(WSCrect* rect);
    WSDLEX32 virtual void onActivate();
    WSDLEX32 virtual void onGuiPolicyChange(long);

    WSDLEX32 virtual void adjustForm();
    WSDLEX32 virtual char* getDefaultProperty();

    WSMFguiClassDef(WSCmessageDialog,WSCbaseDialog);
    WSMFversionDef(WSCmessageDialog);
};

extern WSDLEX WSCmessageDialog* WSGIappMessageDialog();

#endif
